<!-- (an executive summary of the changes, ideally in one sentence) -->
This PR...

## Changes
<!-- (major technical changes list) -->

-

## Checklist

- [ ] tested with Python3.9
- [ ] run `make check` or `make fix` for the formatting check
- [ ] signed commits
- [ ] updated documentation (e.g. parameter description, inline doc, docs.nitrokey)
- [ ] added labels

## Test Environment and Execution

- OS:
- device's model:
- device's firmware version:

### Relevant Output Example
<!-- (makes sense for the bigger UI changes, as well as to explain changes in the behavior) -->

<!-- (please close relevant tickets with the Fixes keyword) -->
Fixes #
